@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: Filter_Rank.cpp 1921 2014-01-09 10:24:11Z oconrad $
+ * Version $Id: Filter_Rank.cpp 2064 2014-03-21 13:20:57Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -130,7 +130,7 @@ CFilter_Rank::CFilter_Rank(void)
 //---------------------------------------------------------
 bool CFilter_Rank::On_Execute(void)
 {
-	int			x, y, ix, iy;
+	int			x, y;
 	double		Rank;
 	CSG_Grid	*pResult;
 
