@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: Grid_SortRaster.cpp 1891 2013-12-04 17:50:43Z oconrad $
+ * Version $Id: Grid_SortRaster.cpp 2072 2014-03-31 08:50:43Z reklov_w $
  *********************************************************/
 /*******************************************************************************
     SortRaster.cpp
@@ -17,7 +17,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, 5th Floor, Boston, MA 02110-1301, USA
 *******************************************************************************/ 
 
 #include "Grid_SortRaster.h"
@@ -68,8 +68,10 @@ bool CSortRaster::On_Execute(void)
 
 	pIndex->Set_NoData_Value(0.0);
 
-	for(int i=0, Index=0, ix, iy; i<Get_NCells() && Set_Progress(i, Get_NCells()); i++)
+	for(sLong i=0, Index=0; i<Get_NCells() && Set_Progress(i, Get_NCells()); i++)
 	{
+		int	ix, iy;
+
 		pGrid->Get_Sorted(i, ix, iy, bDown, false);
 
 		if( pGrid->is_NoData(ix, iy) )
