@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: Grid_To_Contour.h 1246 2011-11-25 13:42:38Z oconrad $
+ * Version $Id: Grid_To_Contour.h 1921 2014-01-09 10:24:11Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -35,7 +35,7 @@
 // You should have received a copy of the GNU General    //
 // Public License along with this program; if not,       //
 // write to the Free Software Foundation, Inc.,          //
-// 59 Temple Place - Suite 330, Boston, MA 02111-1307,   //
+// 51 Franklin Street, 5th Floor, Boston, MA 02110-1301, //
 // USA.                                                  //
 //                                                       //
 //-------------------------------------------------------//
@@ -76,7 +76,7 @@
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-class CGrid_To_Contour : public CSG_Module_Grid  
+class CGrid_To_Contour : public CSG_Module_Grid
 {
 public:
 	CGrid_To_Contour(void);
@@ -98,6 +98,7 @@ private:
 
 	CSG_Shapes				*pLayer;
 
+	int						m_iFormat;
 
 	void					Contour_Create		(double zStart, double zStop, double zDist);
 	void					Contour_Find		(int x, int y, double z, bool doRow, int ID);
