@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: grid_operation.cpp 1921 2014-01-09 10:24:11Z oconrad $
+ * Version $Id: grid_operation.cpp 2064 2014-03-21 13:20:57Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -94,7 +94,7 @@ bool CSG_Grid::Assign(double Value)
 		}
 		else
 		{
-			for(long n=0; n<Get_NCells(); n++)
+			for(sLong n=0; n<Get_NCells(); n++)
 			{
 				Set_Value(n, Value);
 			}
