@@ -35,7 +35,7 @@
 // You should have received a copy of the GNU General    //
 // Public License along with this program; if not,       //
 // write to the Free Software Foundation, Inc.,          //
-// 59 Temple Place - Suite 330, Boston, MA 02111-1307,   //
+// 51 Franklin Street, 5th Floor, Boston, MA 02110-1301, //
 // USA.                                                  //
 //                                                       //
 //-------------------------------------------------------//
@@ -100,6 +100,8 @@ private:
 
 	class CData_Source_ODBC			*m_pODBC;
 
+	class CData_Source_PgSQL		*m_pPgSQL;
+
 
 	bool							_Show_Page				(wxWindow *pPage);
 	bool							_Hide_Page				(wxWindow *pPage);
