@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: parameters_control.cpp 1921 2014-01-09 10:24:11Z oconrad $
+ * Version $Id: parameters_control.cpp 2078 2014-04-02 16:35:47Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -83,9 +83,74 @@
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-#ifndef _SAGA_LINUX
-	#define	PG_USE_MANAGER
-#endif
+class CParameters_Grid : public wxPropertyGrid
+{
+	DECLARE_CLASS(CParameters_Grid)
+
+public:
+	CParameters_Grid(void)
+	{}
+
+	CParameters_Grid(wxWindow *pParent, wxWindowID id = wxID_ANY, const wxPoint &pos = wxDefaultPosition, const wxSize &size = wxDefaultSize, long style = wxPG_DEFAULT_STYLE, const wxString &name = wxPropertyGridNameStr)
+	:	wxPropertyGrid(pParent, id, pos, size, style, name)
+	{}
+
+	virtual wxStatusBar *		GetStatusBar		(void)	{	return( NULL );	}
+
+	void						On_Key				(wxKeyEvent &event)
+	{
+		event.Skip();
+
+		wxPostEvent(GetParent()->GetParent(), event);
+	}
+
+	//-----------------------------------------------------
+	DECLARE_EVENT_TABLE()
+};
+
+//---------------------------------------------------------
+IMPLEMENT_CLASS(CParameters_Grid, wxPropertyGrid)
+
+//---------------------------------------------------------
+BEGIN_EVENT_TABLE(CParameters_Grid, wxPropertyGrid)
+	EVT_KEY_DOWN		(CParameters_Grid::On_Key)
+END_EVENT_TABLE()
+
+
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+class CParameters_Grid_Manager : public wxPropertyGridManager
+{
+public:
+	CParameters_Grid_Manager(void)	{}
+
+	virtual wxPropertyGrid *	CreatePropertyGrid	(void) const
+	{
+		return( new CParameters_Grid() );
+	}
+
+	wxPropertyGrid *			Initialize			(wxWindow *pParent)
+	{
+		Create(pParent, ID_WND_PARM, wxDefaultPosition, wxDefaultSize,
+			 wxPG_BOLD_MODIFIED
+			|wxPG_SPLITTER_AUTO_CENTER
+		//	|wxPG_AUTO_SORT
+		//	|wxPG_HIDE_MARGIN
+		//	|wxPG_STATIC_SPLITTER
+		//	|wxPG_HIDE_CATEGORIES
+		//	|wxPG_LIMITED_EDITING
+			|wxPG_DESCRIPTION
+			|wxBORDER_NONE
+			|wxTAB_TRAVERSAL
+		);
+
+		return( GetGrid() );
+	}
+
+};
 
 
 ///////////////////////////////////////////////////////////
@@ -100,11 +165,10 @@ IMPLEMENT_CLASS(CParameters_Control, wxPanel)
 //---------------------------------------------------------
 BEGIN_EVENT_TABLE(CParameters_Control, wxPanel)
 	EVT_SIZE			(CParameters_Control::On_Size)
+	EVT_KEY_DOWN		(CParameters_Control::On_Key)
 
-	EVT_PG_SELECTED		(ID_WND_PARM_PG_ACTIVE, CParameters_Control::On_PG_Selected)
-	EVT_PG_SELECTED		(ID_WND_PARM_PG_DIALOG, CParameters_Control::On_PG_Selected)
-	EVT_PG_CHANGED		(ID_WND_PARM_PG_ACTIVE, CParameters_Control::On_PG_Changed)
-	EVT_PG_CHANGED		(ID_WND_PARM_PG_DIALOG, CParameters_Control::On_PG_Changed)
+	EVT_PG_SELECTED		(ID_WND_PARM, CParameters_Control::On_PG_Selected)
+	EVT_PG_CHANGED		(ID_WND_PARM, CParameters_Control::On_PG_Changed)
 END_EVENT_TABLE()
 
 
@@ -118,49 +182,18 @@ END_EVENT_TABLE()
 CParameters_Control::CParameters_Control(wxWindow *pParent, bool bDialog)
 	: wxPanel(pParent, -1, wxDefaultPosition, wxDefaultSize, wxNO_BORDER|wxCLIP_CHILDREN)
 {
-	m_pParameters	= new CSG_Parameters();
+	m_pParameters	= new CSG_Parameters;
 	m_pOriginal		= NULL;
 
-#ifdef PG_USE_MANAGER
-	m_pPGM	= new wxPropertyGridManager(this, bDialog ? ID_WND_PARM_PG_DIALOG : ID_WND_PARM_PG_ACTIVE, wxDefaultPosition, wxDefaultSize,
-		 wxPG_BOLD_MODIFIED
-		|wxPG_SPLITTER_AUTO_CENTER
-	//	|wxPG_AUTO_SORT
-	//	|wxPG_HIDE_MARGIN
-	//	|wxPG_STATIC_SPLITTER
-	//	|wxPG_HIDE_CATEGORIES
-	//	|wxPG_LIMITED_EDITING
-		|wxTAB_TRAVERSAL
-	//	|wxPG_TOOLBAR
-		|wxPG_DESCRIPTION
-	//	|wxPG_COMPACTOR
-	//	|wxBORDER_SUNKEN
-		|wxBORDER_NONE
-	);
+	m_bFocus		= 0;
 
-	m_pPG	= m_pPGM->GetGrid();
+	CParameters_Grid_Manager	*pPGM	= new CParameters_Grid_Manager;
+	
+	m_pPG	= pPGM->Initialize(this);
 
-	m_pPGM->SetDescBoxHeight(bDialog ? 100 : 50);
-#else
-	m_pPG	= new wxPropertyGrid(this, bDialog ? ID_WND_PARM_PG_DIALOG : ID_WND_PARM_PG_ACTIVE, wxDefaultPosition, wxDefaultSize,
-		 wxPG_BOLD_MODIFIED
-		|wxPG_SPLITTER_AUTO_CENTER
-	//	|wxPG_AUTO_SORT
-	//	|wxPG_HIDE_MARGIN
-	//	|wxPG_STATIC_SPLITTER
-	//	|wxPG_HIDE_CATEGORIES
-	//	|wxPG_LIMITED_EDITING
-		|wxTAB_TRAVERSAL
-	//	|wxPG_TOOLBAR
-		|wxPG_DESCRIPTION
-	//	|wxPG_COMPACTOR
-	//	|wxBORDER_SUNKEN
-		|wxBORDER_NONE
-	);
+//	pPGM->SetDescBoxHeight(bDialog ? 100 : 50);
 
-	m_pPGM	= NULL;
-
-#endif
+	m_pPG->AddActionTrigger(wxPG_ACTION_PRESS_BUTTON , WXK_SPACE);
 
 //	m_pPG->SetExtraStyle(wxPG_EX_HELP_AS_TOOLTIPS);
 //	m_pPG->SetCellDisabledTextColour(wxColour(200, 200, 200));
@@ -184,28 +217,49 @@ CParameters_Control::~CParameters_Control(void)
 //---------------------------------------------------------
 void CParameters_Control::On_Size(wxSizeEvent &event)
 {
-	if( m_pPGM )
+	if( m_pPG && event.GetSize().GetWidth() > 0 && event.GetSize().GetHeight() > 0 )
 	{
-		m_pPGM->SetSize(GetClientSize());
-	}
-	else
-	{
-		m_pPG ->SetSize(GetClientSize());
-	}
+		m_pPG->GetParent()->SetSize(event.GetSize());
 
-	m_pPG->CenterSplitter(true);
+		m_pPG->CenterSplitter(true);
+	}
 
 	event.Skip();
 }
 
 //---------------------------------------------------------
-void CParameters_Control::On_PG_Selected(wxPropertyGridEvent &WXUNUSED(event))
-{}
+void CParameters_Control::On_Key(wxKeyEvent &event)
+{
+	if( event.GetKeyCode() == WXK_RETURN )
+	{
+		wxPostEvent(GetParent(), event);
+	}
+
+	event.Skip();
+}
+
+//---------------------------------------------------------
+void CParameters_Control::On_PG_Selected(wxPropertyGridEvent &event)
+{
+	if( m_bFocus == 0 && m_pParameters && m_pOriginal )
+	{
+		SetFocus();
+	}
+
+	event.Skip();
+}
 
 //---------------------------------------------------------
 void CParameters_Control::On_PG_Changed(wxPropertyGridEvent &event)
 {
 	_Set_Parameter(event.GetPropertyName());
+
+	if( event.GetProperty() )
+	{
+		m_pPG->SelectProperty(event.GetProperty());
+	}
+
+	event.Skip();
 }
 
 
@@ -225,6 +279,7 @@ bool CParameters_Control::Save_Changes(bool bSilent)
 		m_bModified	= false;
 
 		m_pPG->ClearModifiedStatus();
+		m_pPG->Refresh();
 
 		return( true );
 	}
@@ -319,6 +374,8 @@ bool CParameters_Control::Set_Parameters(CSG_Parameters *pParameters)
 {
 	if( pParameters != m_pParameters )
 	{
+		m_bFocus++;
+
 		m_pPG->Freeze();
 
 		m_bModified	= false;
@@ -356,6 +413,8 @@ bool CParameters_Control::Set_Parameters(CSG_Parameters *pParameters)
 		}
 
 		m_pPG->Thaw();
+
+		m_bFocus--;
 	}
 
 	//-----------------------------------------------------
