@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: res_commands.cpp 1921 2014-01-09 10:24:11Z oconrad $
+ * Version $Id: res_commands.cpp 2039 2014-03-05 13:26:00Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -113,7 +113,8 @@ wxString CMD_Get_Name(int Cmd_ID)
 	case ID_CMD_WKSP_ITEM_SETTINGS_COPY:return( _TL("Copy Settings from other Layer") );
 	case ID_CMD_WKSP_ITEM_SEARCH:		return( _TL("Search for...") );
 
-	case ID_CMD_WKSP_OPEN:				return( _TL("Load") );
+	case ID_CMD_WKSP_OPEN:				return( _TL("Open") );
+	case ID_CMD_WKSP_SAVE:				return( _TL("Save All") );
 
 	case ID_CMD_INFO_CLEAR:				return( _TL("Clear") );
 	case ID_CMD_INFO_COPY:				return( _TL("Copy") );
@@ -131,11 +132,12 @@ wxString CMD_Get_Name(int Cmd_ID)
 	case ID_CMD_DB_TABLE_INFO:			return( _TL("Field Description") );
 	case ID_CMD_DB_TABLE_FROM_QUERY:	return( _TL("Query") );
 
-	case ID_CMD_MODULES_OPEN:			return( _TL("Load Module Library") );
+	case ID_CMD_MODULES_OPEN:			return( _TL("Load Tool Library") );
+	case ID_CMD_MODULES_SEARCH:			return( _TL("Find and Run Tool") );
 	case ID_CMD_MODULES_SAVE_SCRIPT:	return( _TL("Create Script Command File") );
-	case ID_CMD_MODULES_SAVE_DOCS:		return( _TL("Create Module Description Files") );
+	case ID_CMD_MODULES_SAVE_DOCS:		return( _TL("Create Tool Description Files") );
 
-	case ID_CMD_DATA_PROJECT_NEW:		return( _TL("New Project") );
+	case ID_CMD_DATA_PROJECT_NEW:		return( _TL("Close All") );
 	case ID_CMD_DATA_PROJECT_OPEN:		return( _TL("Load Project") );
 	case ID_CMD_DATA_PROJECT_OPEN_ADD:	return( _TL("Add Project") );
 	case ID_CMD_DATA_PROJECT_SAVE:		return( _TL("Save Project") );
@@ -144,6 +146,7 @@ wxString CMD_Get_Name(int Cmd_ID)
 	case ID_CMD_DATA_LEGEND_SIZE_INC:	return( _TL("Increase Legend Size") );
 	case ID_CMD_DATA_LEGEND_SIZE_DEC:	return( _TL("Decrease Legend Size") );
 	case ID_CMD_DATA_HISTORY_CLEAR:		return( _TL("Clear History") );
+	case ID_CMD_DATA_PROJECTION:		return( _TL("Spatial Reference") );
 
 	case ID_CMD_GRIDS_OPEN:
 	case ID_CMD_SHAPES_OPEN:
@@ -197,50 +200,58 @@ wxString CMD_Get_Name(int Cmd_ID)
 	case ID_CMD_SHAPES_EDIT_DEL_SHAPE:	return( _TL("Delete Selected Shape(s)") );
 	case ID_CMD_SHAPES_EDIT_DEL_PART:	return( _TL("Delete Selected Part") );
 	case ID_CMD_SHAPES_EDIT_DEL_POINT:	return( _TL("Delete Selected Point") );
+	case ID_CMD_SHAPES_EDIT_SPLIT:		return( _TL("Split with Line") );
+	case ID_CMD_SHAPES_EDIT_MERGE:		return( _TL("Merge Selection") );
+	case ID_CMD_SHAPES_EDIT_MOVE:		return( _TL("Move") );
 
 	case ID_CMD_POINTCLOUD_RANGE_MINMAX:		return( _TL("Set Range to Minmum/Maximum") );
 	case ID_CMD_POINTCLOUD_RANGE_STDDEV150:		return( _TL("Set Range to Standard Deviation (1.5)") );
 	case ID_CMD_POINTCLOUD_RANGE_STDDEV200:		return( _TL("Set Range to Standard Deviation (2.0)") );
 
-	case ID_CMD_MAP_3D_SHOW:
+	case ID_CMD_MAPS_SHOW:						return( _TL("Show Map") );
 	case ID_CMD_MAPS_3D_SHOW:					return( _TL("Show 3D-View") );
-	case ID_CMD_MAP_LAYOUT_SHOW:
 	case ID_CMD_MAPS_LAYOUT_SHOW:				return( _TL("Show Print Layout") );
-	case ID_CMD_MAP_SAVE_IMAGE_ON_CHANGE:
+	case ID_CMD_MAPS_SAVE_IMAGE:				return( _TL("Save As Image...") );
 	case ID_CMD_MAPS_SAVE_IMAGE_ON_CHANGE:		return( _TL("Save As Image when changed") );
 	case ID_CMD_MAPS_SAVE_IMAGE_TO_MEMORY:		return( _TL("Save As Image to Workspace") );
-	case ID_CMD_MAP_SAVE_IMAGE:
-	case ID_CMD_MAPS_SAVE_IMAGE:				return( _TL("Save As Image...") );
 	case ID_CMD_MAPS_SAVE_TO_CLIPBOARD:			return( _TL("Copy Map to Clipboard [Ctrl+C]") );
 	case ID_CMD_MAPS_SAVE_TO_CLIPBOARD_LEGEND:	return( _TL("Copy Legend to Clipboard [Ctrl+L]") );
-	case ID_CMD_MAP_SYNCHRONIZE:				return( _TL("Synchronise Map Extents") );
-	case ID_CMD_MAP_SCALEBAR:					return( _TL("Scale Bar") );
-
-	case ID_CMD_MAPS_SHOW:				return( _TL("Show Map") );
-	case ID_CMD_MAPS_LAYER_SHOW:		return( _TL("Show Layer") );
-	case ID_CMD_MAPS_MOVE_TOP:			return( _TL("Move To Top") );
-	case ID_CMD_MAPS_MOVE_BOTTOM:		return( _TL("Move To Bottom") );
-	case ID_CMD_MAPS_MOVE_UP:			return( _TL("Move Up") );
-	case ID_CMD_MAPS_MOVE_DOWN:			return( _TL("Move Down") );
-	case ID_CMD_MAPS_GRID_FITCOLORS:	return( _TL("Fit Grid Colors To Map Extent") );
+	case ID_CMD_MAPS_SYNCHRONIZE:				return( _TL("Synchronise Map Extents") );
+	case ID_CMD_MAPS_SCALEBAR:					return( _TL("Scale Bar") );
+	case ID_CMD_MAPS_PROJECTION:				return( _TL("Spatial Reference") );
+	case ID_CMD_MAPS_GRATICULE_ADD:				return( _TL("Add Graticule") );
+	case ID_CMD_MAPS_LAYER_SHOW:				return( _TL("Show Layer") );
+	case ID_CMD_MAPS_MOVE_TOP:					return( _TL("Move To Top") );
+	case ID_CMD_MAPS_MOVE_BOTTOM:				return( _TL("Move To Bottom") );
+	case ID_CMD_MAPS_MOVE_UP:					return( _TL("Move Up") );
+	case ID_CMD_MAPS_MOVE_DOWN:					return( _TL("Move Down") );
+	case ID_CMD_MAPS_GRID_FITCOLORS:			return( _TL("Fit Grid Colors To Map Extent") );
 
 	//-----------------------------------------------------
 	// Views...
 
-	case ID_CMD_MAP_MODE_ZOOM:			return( _TL("Zoom") );
-	case ID_CMD_MAP_MODE_PAN:			return( _TL("Pan") );
-	case ID_CMD_MAP_MODE_SELECT:		return( _TL("Action") );
-	case ID_CMD_MAP_MODE_DISTANCE:		return( _TL("Measure Distance") );
-	case ID_CMD_MAP_CLOSE:				return( _TL("Close") );
-	case ID_CMD_MAP_TOOLBAR:			return( _TL("Show Toolbar") );
-	case ID_CMD_MAP_LEGEND_VERTICAL:	return( _TL("Show Vertical Legend") );
-	case ID_CMD_MAP_LEGEND_HORIZONTAL:	return( _TL("Show Horizontal Legend") );
-	case ID_CMD_MAP_ZOOM_BACK:			return( _TL("Zoom To Previous Extent") );
-	case ID_CMD_MAP_ZOOM_FORWARD:		return( _TL("Zoom To Next Extent") );
-	case ID_CMD_MAP_ZOOM_FULL:			return( _TL("Zoom To Full Extent") );
-	case ID_CMD_MAP_ZOOM_ACTIVE:		return( _TL("Zoom To Active Layer") );
-	case ID_CMD_MAP_ZOOM_SELECTION:		return( _TL("Zoom To Selection") );
-	case ID_CMD_MAP_ZOOM_EXTENT:		return( _TL("Zoom To Extent") );
+	case ID_CMD_MAP_CLOSE:						return( _TL("Close") );
+	case ID_CMD_MAP_TOOLBAR:					return( _TL("Show Toolbar") );
+	case ID_CMD_MAP_3D_SHOW:					return( CMD_Get_Name(ID_CMD_MAPS_3D_SHOW) );
+	case ID_CMD_MAP_LAYOUT_SHOW:				return( CMD_Get_Name(ID_CMD_MAPS_LAYOUT_SHOW) );
+	case ID_CMD_MAP_SCALEBAR:					return( CMD_Get_Name(ID_CMD_MAPS_SCALEBAR) );
+	case ID_CMD_MAP_GRATICULE_ADD:				return( CMD_Get_Name(ID_CMD_MAPS_GRATICULE_ADD) );
+	case ID_CMD_MAP_SAVE_IMAGE:					return( CMD_Get_Name(ID_CMD_MAPS_SAVE_IMAGE) );
+	case ID_CMD_MAP_SAVE_IMAGE_ON_CHANGE:		return( CMD_Get_Name(ID_CMD_MAPS_SAVE_IMAGE_ON_CHANGE) );
+	case ID_CMD_MAP_SYNCHRONIZE:				return( CMD_Get_Name(ID_CMD_MAPS_SYNCHRONIZE) );
+	case ID_CMD_MAP_NORTH_ARROW:				return( _TL("North Arrow") );
+	case ID_CMD_MAP_LEGEND_VERTICAL:			return( _TL("Show Vertical Legend") );
+	case ID_CMD_MAP_LEGEND_HORIZONTAL:			return( _TL("Show Horizontal Legend") );
+	case ID_CMD_MAP_MODE_ZOOM:					return( _TL("Zoom") );
+	case ID_CMD_MAP_MODE_PAN:					return( _TL("Pan") );
+	case ID_CMD_MAP_MODE_SELECT:				return( _TL("Action") );
+	case ID_CMD_MAP_MODE_DISTANCE:				return( _TL("Measure Distance") );
+	case ID_CMD_MAP_ZOOM_FULL:					return( _TL("Zoom To Full Extent") );
+	case ID_CMD_MAP_ZOOM_BACK:					return( _TL("Zoom To Previous Extent") );
+	case ID_CMD_MAP_ZOOM_FORWARD:				return( _TL("Zoom To Next Extent") );
+	case ID_CMD_MAP_ZOOM_ACTIVE:				return( _TL("Zoom To Active Layer") );
+	case ID_CMD_MAP_ZOOM_SELECTION:				return( _TL("Zoom To Selection") );
+	case ID_CMD_MAP_ZOOM_EXTENT:				return( _TL("Zoom To Extent") );
 
 	case ID_CMD_MAP3D_PARAMETERS:		return( _TL("Properties") );
 	case ID_CMD_MAP3D_ROTATE_X_LESS:	return( _TL("Up") );
@@ -335,7 +346,9 @@ int CMD_Get_ImageID(int Cmd_ID)
 	case ID_CMD_FRAME_INFO_SHOW:		return( ID_IMG_TB_INFO );
 	case ID_CMD_FRAME_HELP:				return( ID_IMG_TB_HELP );
 	case ID_CMD_WKSP_OPEN:				return( ID_IMG_TB_OPEN );
+	case ID_CMD_WKSP_SAVE:				return( ID_IMG_TB_SAVE );
 	case ID_CMD_MODULES_OPEN:			return( ID_IMG_TB_OPEN_MODULE );
+	case ID_CMD_MODULES_SEARCH:			return( ID_IMG_NB_WKSP_MODULES );
 	case ID_CMD_TABLES_OPEN:			return( ID_IMG_TB_OPEN_TABLE );
 	case ID_CMD_SHAPES_OPEN:			return( ID_IMG_TB_OPEN_SHAPES );
 	case ID_CMD_GRIDS_OPEN:				return( ID_IMG_TB_OPEN_GRID );
@@ -359,8 +372,10 @@ int CMD_Get_ImageID(int Cmd_ID)
 	case ID_CMD_MAPS_SAVE_TO_CLIPBOARD:			break;
 	case ID_CMD_MAPS_SAVE_TO_CLIPBOARD_LEGEND:	break;
 	case ID_CMD_MAPS_SAVE_IMAGE:				break;
+	case ID_CMD_MAP_NORTH_ARROW:		return( ID_IMG_TB_MAP_NORTH_ARROW );
 	case ID_CMD_MAP_SYNCHRONIZE:		return( ID_IMG_TB_MAP_SYNCHRONIZE );
 	case ID_CMD_MAP_SCALEBAR:			return( ID_IMG_TB_MAP_SCALEBAR );
+	case ID_CMD_MAP_GRATICULE_ADD:				break;
 	case ID_CMD_MAP_LEGEND_VERTICAL:	return( ID_IMG_TB_MAP_LEGEND_VERTICAL );
 	case ID_CMD_MAP_LEGEND_HORIZONTAL:	return( ID_IMG_TB_MAP_LEGEND_HORIZONTAL );
 
