@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: res_commands.h 1921 2014-01-09 10:24:11Z oconrad $
+ * Version $Id: res_commands.h 2017 2014-02-25 15:48:09Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -114,6 +114,7 @@ enum ID_COMMANDS
 	//-----------------------------------------------------
 	ID_CMD_WKSP_FIRST,
 	ID_CMD_WKSP_OPEN,
+	ID_CMD_WKSP_SAVE,
 	ID_CMD_WKSP_ITEM_RETURN,
 	ID_CMD_WKSP_ITEM_CLOSE,
 	ID_CMD_WKSP_ITEM_SETTINGS_LOAD,
@@ -141,6 +142,7 @@ enum ID_COMMANDS
 	ID_CMD_MODULES_RECENT_FIRST,
 	ID_CMD_MODULES_RECENT_LAST		= RECENT_COUNT + ID_CMD_MODULES_RECENT_FIRST,
 	ID_CMD_MODULES_OPEN,
+	ID_CMD_MODULES_SEARCH,
 	ID_CMD_MODULES_SAVE_SCRIPT,
 	ID_CMD_MODULES_SAVE_DOCS,
 	ID_CMD_MODULES_LAST,
@@ -157,6 +159,7 @@ enum ID_COMMANDS
 	ID_CMD_DATA_LEGEND_SIZE_INC,
 	ID_CMD_DATA_LEGEND_SIZE_DEC,
 	ID_CMD_DATA_HISTORY_CLEAR,
+	ID_CMD_DATA_PROJECTION,
 	ID_CMD_DATA_LAST,
 
 	ID_CMD_GRIDS_FIRST,
@@ -198,6 +201,9 @@ enum ID_COMMANDS
 	ID_CMD_SHAPES_EDIT_DEL_SHAPE,
 	ID_CMD_SHAPES_EDIT_DEL_PART,
 	ID_CMD_SHAPES_EDIT_DEL_POINT,
+	ID_CMD_SHAPES_EDIT_SPLIT,
+	ID_CMD_SHAPES_EDIT_MERGE,
+	ID_CMD_SHAPES_EDIT_MOVE,
 	ID_CMD_SHAPES_LAST,
 
 	ID_CMD_TABLES_FIRST,
@@ -237,10 +243,14 @@ enum ID_COMMANDS
 	ID_CMD_MAPS_3D_SHOW,
 	ID_CMD_MAPS_LAYOUT_SHOW,
 	ID_CMD_MAPS_SAVE_IMAGE,
-	ID_CMD_MAPS_SAVE_TO_CLIPBOARD,
-	ID_CMD_MAPS_SAVE_TO_CLIPBOARD_LEGEND,
 	ID_CMD_MAPS_SAVE_IMAGE_ON_CHANGE,
 	ID_CMD_MAPS_SAVE_IMAGE_TO_MEMORY,
+	ID_CMD_MAPS_SAVE_TO_CLIPBOARD,
+	ID_CMD_MAPS_SAVE_TO_CLIPBOARD_LEGEND,
+	ID_CMD_MAPS_SYNCHRONIZE,
+	ID_CMD_MAPS_SCALEBAR,
+	ID_CMD_MAPS_PROJECTION,
+	ID_CMD_MAPS_GRATICULE_ADD,
 	ID_CMD_MAPS_LAYER_SHOW,
 	ID_CMD_MAPS_MOVE_TOP,
 	ID_CMD_MAPS_MOVE_BOTTOM,
@@ -252,7 +262,7 @@ enum ID_COMMANDS
 	ID_CMD_WKSP_LAST,
 
 	//-----------------------------------------------------
-	ID_CMD_CHILD_FIRST,
+	ID_CMD_CHILD_FIRST,	// Child Window Commands
 
 	ID_CMD_MAP_FIRST,
 	ID_CMD_MAP_CLOSE,
@@ -260,21 +270,23 @@ enum ID_COMMANDS
 	ID_CMD_MAP_3D_SHOW,
 	ID_CMD_MAP_LAYOUT_SHOW,
 	ID_CMD_MAP_SCALEBAR,
+	ID_CMD_MAP_GRATICULE_ADD,
 	ID_CMD_MAP_SAVE_IMAGE,
 	ID_CMD_MAP_SAVE_IMAGE_ON_CHANGE,
 	ID_CMD_MAP_SYNCHRONIZE,
+	ID_CMD_MAP_NORTH_ARROW,
 	ID_CMD_MAP_LEGEND_VERTICAL,
 	ID_CMD_MAP_LEGEND_HORIZONTAL,
+	ID_CMD_MAP_MODE_ZOOM,
+	ID_CMD_MAP_MODE_PAN,
+	ID_CMD_MAP_MODE_SELECT,
+	ID_CMD_MAP_MODE_DISTANCE,
 	ID_CMD_MAP_ZOOM_FULL,
 	ID_CMD_MAP_ZOOM_BACK,
 	ID_CMD_MAP_ZOOM_FORWARD,
 	ID_CMD_MAP_ZOOM_ACTIVE,
 	ID_CMD_MAP_ZOOM_SELECTION,
 	ID_CMD_MAP_ZOOM_EXTENT,
-	ID_CMD_MAP_MODE_ZOOM,
-	ID_CMD_MAP_MODE_PAN,
-	ID_CMD_MAP_MODE_SELECT,
-	ID_CMD_MAP_MODE_DISTANCE,
 	ID_CMD_MAP_LAST,
 
 	ID_CMD_MAP3D_FIRST,
@@ -358,7 +370,7 @@ enum ID_COMMANDS
 	ID_CMD_LAYOUT_FIT_SCALE,
 	ID_CMD_LAYOUT_LAST,
 
-	ID_CMD_CHILD_LAST,
+	ID_CMD_CHILD_LAST,	// Child Window Commands
 
 	//-----------------------------------------------------
 	ID_CMD_MODULE_FIRST,
