@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: view_table.cpp 1921 2014-01-09 10:24:11Z oconrad $
+ * Version $Id: view_table.cpp 2067 2014-03-24 10:53:19Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -118,17 +118,11 @@ END_EVENT_TABLE()
 
 //---------------------------------------------------------
 CVIEW_Table::CVIEW_Table(CWKSP_Table *pTable)
-	: CVIEW_Base(ID_VIEW_TABLE, pTable->Get_Name(), ID_IMG_WND_TABLE)
+	: CVIEW_Base(pTable, ID_VIEW_TABLE, pTable->Get_Name(), ID_IMG_WND_TABLE, false)
 {
-	m_pTable	= pTable;
+	m_pControl	= new CVIEW_Table_Control(this, pTable->Get_Table(), 0);
 
-	m_pControl	= new CVIEW_Table_Control(this, m_pTable->Get_Table(), 0);
-}
-
-//---------------------------------------------------------
-CVIEW_Table::~CVIEW_Table(void)
-{
-	m_pTable->View_Closes(this);
+	Do_Show();
 }
 
 
@@ -173,6 +167,25 @@ wxToolBarBase * CVIEW_Table::_Create_ToolBar(void)
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+void CVIEW_Table::Do_Update(void)
+{
+	m_pControl->Update_Table();
+}
+
+//---------------------------------------------------------
+void CVIEW_Table::Update_Selection(void)
+{
+	m_pControl->Update_Selection();
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
@@ -290,25 +303,6 @@ void CVIEW_Table::On_Sel_To_Top_UI(wxUpdateUIEvent &event)
 }
 
 
-///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
-///////////////////////////////////////////////////////////
-
-//---------------------------------------------------------
-void CVIEW_Table::Update_Table(void)
-{
-	m_pControl->Update_Table();
-}
-
-//---------------------------------------------------------
-void CVIEW_Table::Update_Selection(void)
-{
-	m_pControl->Update_Selection();
-}
-
-
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
