@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: view_table.h 1921 2014-01-09 10:24:11Z oconrad $
+ * Version $Id: view_table.h 2061 2014-03-20 11:48:01Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -84,15 +84,24 @@
 //---------------------------------------------------------
 class CVIEW_Table : public CVIEW_Base
 {
-	DECLARE_CLASS(CVIEW_Table)
-
 public:
 	CVIEW_Table(class CWKSP_Table *pTable);
-	virtual ~CVIEW_Table(void);
 
 	static class wxToolBarBase *	_Create_ToolBar		(void);
 	static class wxMenu *			_Create_Menu		(void);
 
+	virtual void					Do_Update			(void);
+
+	void							Update_Selection	(void);
+
+
+private:
+
+	class CWKSP_Table				*m_pTable;
+
+	class CVIEW_Table_Control		*m_pControl;
+
+
 	void							On_Field_Add		(wxCommandEvent  &event);
 	void							On_Field_Add_UI		(wxUpdateUIEvent &event);
 	void							On_Field_Del		(wxCommandEvent  &event);
@@ -115,19 +124,10 @@ public:
 	void							On_Sel_To_Top		(wxCommandEvent  &event);
 	void							On_Sel_To_Top_UI	(wxUpdateUIEvent &event);
 
-	void							Update_Table		(void);
-	void							Update_Selection	(void);
 
-
-private:
-
-	class CWKSP_Table				*m_pTable;
-
-	class CVIEW_Table_Control		*m_pControl;
-
-
-//---------------------------------------------------------
-DECLARE_EVENT_TABLE()
+	//-----------------------------------------------------
+	DECLARE_CLASS(CVIEW_Table)
+	DECLARE_EVENT_TABLE()
 };
 
 
