@@ -1,5 +1,5 @@
 /**********************************************************
- * Version $Id: wksp_shapes_edit.cpp 1921 2014-01-09 10:24:11Z oconrad $
+ * Version $Id: wksp_shapes_edit.cpp 2081 2014-04-03 09:55:43Z oconrad $
  *********************************************************/
 
 ///////////////////////////////////////////////////////////
@@ -96,24 +96,59 @@
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-wxMenu * CWKSP_Shapes::On_Edit_Get_Menu(void)
+wxMenu * CWKSP_Shapes::Edit_Get_Menu(void)
 {
 	wxMenu	*pMenu	= new wxMenu;
 
 	CMD_Menu_Add_Item(pMenu, true , ID_CMD_SHAPES_EDIT_SHAPE);
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_SHAPES_EDIT_ADD_SHAPE);
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_SHAPES_EDIT_DEL_SHAPE);
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_SHAPES_EDIT_ADD_PART);
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_SHAPES_EDIT_DEL_PART);
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_SHAPES_EDIT_DEL_POINT);
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_SHAPES_EDIT_SEL_CLEAR);
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_SHAPES_EDIT_SEL_INVERT);
+
+	if( !is_Editing() )
+	{
+		pMenu->AppendSeparator();
+		CMD_Menu_Add_Item(pMenu, false, ID_CMD_SHAPES_EDIT_ADD_SHAPE);
+		CMD_Menu_Add_Item(pMenu, false, ID_CMD_SHAPES_EDIT_DEL_SHAPE);
+		pMenu->AppendSeparator();
+		CMD_Menu_Add_Item(pMenu, false, ID_CMD_SHAPES_EDIT_SEL_INVERT);
+		CMD_Menu_Add_Item(pMenu, false, ID_CMD_SHAPES_EDIT_SEL_CLEAR);
+
+		if( Get_Shapes()->Get_Selection_Count()  > 1
+		&&  Get_Shapes()->Get_Type() != SHAPE_TYPE_Point )
+		{
+			pMenu->AppendSeparator();
+			CMD_Menu_Add_Item(pMenu, false, ID_CMD_SHAPES_EDIT_MERGE);
+		}
+
+		if( Get_Shapes()->Get_Selection_Count() == 1
+		&& (Get_Shapes()->Get_Type() == SHAPE_TYPE_Polygon
+		||  Get_Shapes()->Get_Type() == SHAPE_TYPE_Line) )
+		{
+			pMenu->AppendSeparator();
+			CMD_Menu_Add_Item(pMenu, false, ID_CMD_SHAPES_EDIT_SPLIT);
+		}
+	}
+	else if( Get_Shapes()->Get_Type() != SHAPE_TYPE_Point )
+	{
+		pMenu->AppendSeparator();
+		CMD_Menu_Add_Item(pMenu, false, ID_CMD_SHAPES_EDIT_ADD_PART);
+		CMD_Menu_Add_Item(pMenu, false, ID_CMD_SHAPES_EDIT_DEL_PART);
+		CMD_Menu_Add_Item(pMenu, false, ID_CMD_SHAPES_EDIT_DEL_POINT);
+
+		pMenu->AppendSeparator();
+
+		if( Get_Shapes()->Get_Type() == SHAPE_TYPE_Line
+		||  Get_Shapes()->Get_Type() == SHAPE_TYPE_Polygon )
+		{
+			CMD_Menu_Add_Item(pMenu, false, ID_CMD_SHAPES_EDIT_SPLIT);
+		}
+
+		CMD_Menu_Add_Item(pMenu,  true, ID_CMD_SHAPES_EDIT_MOVE);
+	}
 
 	return( pMenu );
 }
 
 //---------------------------------------------------------
-TSG_Rect CWKSP_Shapes::On_Edit_Get_Extent(void)
+TSG_Rect CWKSP_Shapes::Edit_Get_Extent(void)
 {
 	if( m_Edit_pShape )
 	{
@@ -136,7 +171,7 @@ TSG_Rect CWKSP_Shapes::On_Edit_Get_Extent(void)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CWKSP_Shapes::On_Edit_On_Key_Down(int KeyCode)
+bool CWKSP_Shapes::Edit_On_Key_Down(int KeyCode)
 {
 	switch( KeyCode )
 	{
@@ -169,42 +204,78 @@ bool CWKSP_Shapes::On_Edit_On_Key_Down(int KeyCode)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CWKSP_Shapes::On_Edit_On_Mouse_Down(CSG_Point Point, double ClientToWorld, int Key)
+bool CWKSP_Shapes::Edit_On_Mouse_Down(CSG_Point Point, double ClientToWorld, int Key)
 {
-	int		iPart, iPoint;
+	CWKSP_Layer::Edit_On_Mouse_Down(Point, ClientToWorld, Key);
+
+	if( !(Key & MODULE_INTERACTIVE_KEY_LEFT) )
+	{
+		return( false );
+	}
 
 	//-----------------------------------------------------
-	if( m_Edit_pShape )
+	switch( m_Edit_Mode )
 	{
-		if( m_Edit_iPart >= 0 && m_Edit_iPoint < 0 )
+	case EDIT_SHAPE_MODE_Split:
+		if( m_Edit_Shapes.Get_Count() > 1 )
 		{
-		}
-		else switch( _Edit_Shape_HitTest(Point, EDIT_TICKMARK_SIZE * ClientToWorld, iPart, iPoint) )
-		{
-		//-------------------------------------------------
-		case 0:	default:
-		case 1:
-			if( m_Edit_iPart != iPart || m_Edit_iPoint != iPoint )
-			{
-				m_Edit_iPart	= iPart;
-				m_Edit_iPoint	= iPoint;
-
-				Update_Views(false);
-			}
-
-			return( true );
-
-		//-------------------------------------------------
-		case 2:
-			m_Edit_pShape->Ins_Point(Point, iPoint, iPart);
-
-			m_Edit_iPart	= iPart;
-			m_Edit_iPoint	= iPoint;
+			m_Edit_Shapes.Get_Shape(1)->Add_Point(Point);
 
 			Update_Views(false);
 
 			return( true );
 		}
+		break;
+
+	case EDIT_SHAPE_MODE_Move:
+		if( m_Edit_Shapes.Get_Count() > 1 && m_Edit_Shapes.Get_Shape(1)->Get_Point_Count() == 0 )
+		{
+			m_Edit_Shapes.Get_Shape(1)->Add_Point(Point);
+
+			return( true );
+		}
+		break;
+
+	case EDIT_SHAPE_MODE_Normal: default:
+		if( m_Edit_pShape )
+		{
+			if( m_Edit_iPart >= 0 && m_Edit_iPoint < 0 )
+			{
+				// NOP
+			}
+			else
+			{
+				int		iPart, iPoint;
+
+				switch( Edit_Shape_HitTest(Point, EDIT_TICKMARK_SIZE * ClientToWorld, iPart, iPoint) )
+				{
+				//-----------------------------------------
+				case 0:	default:
+				case 1:
+					if( m_Edit_iPart != iPart || m_Edit_iPoint != iPoint )
+					{
+						m_Edit_iPart	= iPart;
+						m_Edit_iPoint	= iPoint;
+
+						Update_Views(false);
+					}
+
+					return( true );
+
+				//-----------------------------------------
+				case 2:
+					m_Edit_pShape->Ins_Point(Point, iPoint, iPart);
+
+					m_Edit_iPart	= iPart;
+					m_Edit_iPoint	= iPoint;
+
+					Update_Views(false);
+
+					return( true );
+				}
+			}
+			break;
+		}
 	}
 
 	//-----------------------------------------------------
@@ -212,30 +283,42 @@ bool CWKSP_Shapes::On_Edit_On_Mouse_Down(CSG_Point Point, double ClientToWorld,
 }
 
 //---------------------------------------------------------
-bool CWKSP_Shapes::On_Edit_On_Mouse_Up(CSG_Point Point, double ClientToWorld, int Key)
+bool CWKSP_Shapes::Edit_On_Mouse_Up(CSG_Point Point, double ClientToWorld, int Key)
 {
-	CSG_Rect		rWorld(m_Edit_Mouse_Down, Point);
-	CSG_Table_Record	*pRecord;
-	wxFileName		FileName;
-
-
 	//-----------------------------------------------------
 	if( Key & MODULE_INTERACTIVE_KEY_RIGHT )
 	{
-		if( m_Edit_pShape && m_Edit_iPart >= 0 && m_Edit_iPoint < 0 )
+		switch( m_Edit_Mode )
 		{
-			m_Edit_iPart	= -1;
+		case EDIT_SHAPE_MODE_Split:
+			return( _Edit_Split() );
 
-			Update_Views(false);
+		case EDIT_SHAPE_MODE_Normal:
+			if( m_Edit_pShape && m_Edit_iPart >= 0 && m_Edit_iPoint < 0 )
+			{
+				m_Edit_iPart	= -1;
 
-			return( true );
+				Update_Views(false);
+
+				return( true );
+			}
+			break;
 		}
 	}
 
 	//-----------------------------------------------------
 	else if( m_Edit_pShape )
 	{
-		if( m_Edit_iPart >= 0 )
+		if( m_Edit_Mode == EDIT_SHAPE_MODE_Move )
+		{
+			if( m_Edit_Shapes.Get_Count() > 1 && m_Edit_Shapes.Get_Shape(1)->Get_Point_Count() > 0 )
+			{
+				m_Edit_Shapes.Get_Shape(1)->Add_Point(Point);
+
+				return( _Edit_Move(false) );
+			}
+		}
+		else if( m_Edit_iPart >= 0 )
 		{
 			if( m_Edit_iPoint >= 0 )
 			{
@@ -264,33 +347,31 @@ bool CWKSP_Shapes::On_Edit_On_Mouse_Up(CSG_Point Point, double ClientToWorld, in
 	}
 
 	//-----------------------------------------------------
-	else
+	else if( m_Edit_Mode == EDIT_SHAPE_MODE_Normal )
 	{
-		rWorld.Assign(m_Edit_Mouse_Down, Point);
+		g_pACTIVE->Get_Attributes()->Save_Changes(true);
+
+		CSG_Rect	rWorld(m_Edit_Mouse_Down, Point);
 
 		if( rWorld.Get_XRange() == 0.0 && rWorld.Get_YRange() == 0.0 )
 		{
 			rWorld.Inflate(2.0 * ClientToWorld, false);
 		}
 
-		g_pACTIVE->Get_Attributes()->Set_Attributes();
+		int		Count	= Get_Shapes()->Get_Selection_Count();
 
-		pRecord	= Get_Shapes()->Get_Selection();
-		
 		Get_Shapes()->Select(rWorld, (Key & MODULE_INTERACTIVE_KEY_CTRL) != 0);
 
+		Edit_Set_Index((Key & MODULE_INTERACTIVE_KEY_CTRL) == 0 ? 0 :
+			Count < Get_Shapes()->Get_Selection_Count() || m_Edit_Index >= Get_Shapes()->Get_Selection_Count()
+			? Get_Shapes()->Get_Selection_Count() - 1 : m_Edit_Index
+		);
+
 		if( m_pTable->Get_View() )
 		{
 			m_pTable->Get_View()->Update_Selection();
 		}
 
-		if( pRecord != Get_Shapes()->Get_Selection() )
-		{
-			_Edit_Set_Attributes();
-		}
-
-		pRecord	= Get_Shapes()->Get_Selection();
-
 		Update_Views(false);
 
 		return( true );
@@ -300,49 +381,57 @@ bool CWKSP_Shapes::On_Edit_On_Mouse_Up(CSG_Point Point, double ClientToWorld, in
 }
 
 //---------------------------------------------------------
-bool CWKSP_Shapes::On_Edit_On_Mouse_Move(wxWindow *pMap, CSG_Rect rWorld, wxPoint pt, wxPoint ptLast, int Key)
+bool CWKSP_Shapes::Edit_On_Mouse_Move(wxWindow *pMap, CSG_Rect rWorld, wxPoint pt, wxPoint ptLast, int Key)
 {
-	if( m_Edit_pShape )
+	switch( m_Edit_Mode )
 	{
-		double	ClientToWorld	= rWorld.Get_XRange() / (double)pMap->GetClientSize().x;
-
-		//-------------------------------------------------
-		if( m_Edit_iPart >= 0 && (m_Edit_iPoint < 0 || Key & MODULE_INTERACTIVE_KEY_LEFT) )
+	case EDIT_SHAPE_MODE_Split:
+	case EDIT_SHAPE_MODE_Move:
 		{
-			if( pt.x != ptLast.x || pt.y != ptLast.y )
-			{
-				wxClientDC	dc(pMap);
-				dc.SetLogicalFunction(wxINVERT);
+			CSG_Shape	*pShape	= m_Edit_Shapes.Get_Shape(1);
 
-				_Edit_Shape_Draw_Move(dc, rWorld, ClientToWorld, ptLast);
-				_Edit_Shape_Draw_Move(dc, rWorld, ClientToWorld, pt);
+			if( pShape && pShape->Get_Point_Count() > 0 && (pt.x != ptLast.x || pt.y != ptLast.y) )
+			{
+				wxClientDC	dc(pMap);	dc.SetLogicalFunction(wxINVERT);
+
+				Edit_Shape_Draw_Move(dc, rWorld, ptLast, pShape->Get_Point(0, 0, false));
+				Edit_Shape_Draw_Move(dc, rWorld, pt    , pShape->Get_Point(0, 0, false));
 			}
 
 			return( true );
 		}
 
-		//-------------------------------------------------
-		else
+	//-----------------------------------------------------
+	case EDIT_SHAPE_MODE_Normal: default:
+		if( m_Edit_pShape )
 		{
-			int			iPart, iPoint;
-			CSG_Point	Point(rWorld.Get_XMin() + pt.x * ClientToWorld, rWorld.Get_YMax() - pt.y * ClientToWorld);
-
-			switch( _Edit_Shape_HitTest(Point, EDIT_TICKMARK_SIZE * ClientToWorld, iPart, iPoint) )
+			//---------------------------------------------
+			if( m_Edit_iPart >= 0 && (m_Edit_iPoint < 0 || Key & MODULE_INTERACTIVE_KEY_LEFT) && (pt.x != ptLast.x || pt.y != ptLast.y) )
 			{
-			case 0:	default:
-				pMap->SetCursor(IMG_Get_Cursor(ID_IMG_CRS_SELECT));
-				break;
+				wxClientDC	dc(pMap);	dc.SetLogicalFunction(wxINVERT);
 
-			case 1:
-				pMap->SetCursor(IMG_Get_Cursor(ID_IMG_CRS_EDIT_POINT_MOVE));
-				break;
+				Edit_Shape_Draw_Move(dc, rWorld, ptLast);
+				Edit_Shape_Draw_Move(dc, rWorld, pt);
 
-			case 2:
-				pMap->SetCursor(IMG_Get_Cursor(ID_IMG_CRS_EDIT_POINT_ADD));
-				break;
+				return( true );
 			}
 
-			return( true );
+			//---------------------------------------------
+			else
+			{
+				int			iPart, iPoint;
+				double		ClientToWorld	= rWorld.Get_XRange() / (double)pMap->GetClientSize().x;
+				CSG_Point	Point(rWorld.Get_XMin() + pt.x * ClientToWorld, rWorld.Get_YMax() - pt.y * ClientToWorld);
+
+				switch( Edit_Shape_HitTest(Point, EDIT_TICKMARK_SIZE * ClientToWorld, iPart, iPoint) )
+				{
+				default:	pMap->SetCursor(IMG_Get_Cursor(ID_IMG_CRS_SELECT         ));	break;
+				case  1:	pMap->SetCursor(IMG_Get_Cursor(ID_IMG_CRS_EDIT_POINT_MOVE));	break;
+				case  2:	pMap->SetCursor(IMG_Get_Cursor(ID_IMG_CRS_EDIT_POINT_ADD ));	break;
+				}
+
+				return( true );
+			}
 		}
 	}
 
@@ -357,37 +446,50 @@ bool CWKSP_Shapes::On_Edit_On_Mouse_Move(wxWindow *pMap, CSG_Rect rWorld, wxPoin
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CWKSP_Shapes::_Edit_Set_Attributes(void)
+bool CWKSP_Shapes::Edit_Set_Index(int Index)
 {
-	CSG_Table_Record	*pAttribute, *pRecord;
-
 	m_Edit_Attributes.Del_Records();
 
-	if( (pRecord = Get_Shapes()->Get_Selection()) != NULL )
+	if( Index > Get_Shapes()->Get_Selection_Count() )
 	{
-		for(int i=0; i<Get_Shapes()->Get_Field_Count(); i++)
-		{
-			pAttribute	= m_Edit_Attributes.Add_Record();
-			pAttribute->Set_Value(0, pRecord->Get_Table()->Get_Field_Name(i));
-			pAttribute->Set_Value(1, pRecord->asString(i));
-		}
+		Index	= Get_Shapes()->Get_Selection_Count();
 	}
 
-	g_pACTIVE->Get_Attributes()->Set_Attributes();
+	CSG_Table_Record	*pSelection	= Get_Shapes()->Get_Selection(Index);
+
+	if( pSelection )
+	{
+		m_Edit_Index	= Index;
+
+		for(int i=0; i<Get_Shapes()->Get_Field_Count(); i++)
+		{
+			CSG_Table_Record	*pRecord	= m_Edit_Attributes.Add_Record();
+
+			pRecord->Set_Value(0, pSelection->Get_Table()->Get_Field_Name(i));
+			pRecord->Set_Value(1, pSelection->asString(i));
+		}
+	}
+	else
+	{
+		m_Edit_Index	= 0;
+	}
 
 	return( true );
 }
 
 //---------------------------------------------------------
-bool CWKSP_Shapes::On_Edit_Set_Attributes(void)
+bool CWKSP_Shapes::Edit_Set_Attributes(void)
 {
-	CSG_Table_Record	*pRecord;
+	CSG_Table_Record	*pSelection	= Get_Shapes()->Get_Selection(m_Edit_Index);
 
-	if( (pRecord = Get_Shapes()->Get_Selection()) != NULL )
+	if( pSelection )
 	{
 		for(int i=0; i<m_Edit_Attributes.Get_Record_Count(); i++)
 		{
-			pRecord->Set_Value(i, m_Edit_Attributes.Get_Record(i)->asString(1));
+			if( !pSelection->Set_Value(i, m_Edit_Attributes.Get_Record(i)->asString(1)) )
+			{
+				m_Edit_Attributes.Get_Record(i)->Set_Value(1, pSelection->asString(i));
+			}
 		}
 
 		Update_Views(false);
@@ -399,6 +501,245 @@ bool CWKSP_Shapes::On_Edit_Set_Attributes(void)
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CWKSP_Shapes::_Edit_Merge(void)
+{
+	if( Get_Shapes()->Get_Selection_Count() < 2 || Get_Shapes()->Get_Type() == SHAPE_TYPE_Point )
+	{
+		return( false );
+	}
+
+	//-----------------------------------------------------
+	CSG_Shape	*pMerged	= Get_Shapes()->Get_Selection(0);
+
+	for(int i=1; i<Get_Shapes()->Get_Selection_Count(); i++)
+	{
+		CSG_Shape	*pShape	= Get_Shapes()->Get_Selection(i);
+
+		for(int iPart=0, jPart=pMerged->Get_Part_Count(); iPart<pShape->Get_Part_Count(); iPart++, jPart++)
+		{
+			for(int iPoint=0; iPoint<pShape->Get_Point_Count(iPart); iPoint++)
+			{
+				pMerged->Add_Point(pShape->Get_Point(iPoint, iPart), jPart);
+			}
+		}
+	}
+
+	if( Get_Shapes()->Get_Type() == SHAPE_TYPE_Polygon )
+	{
+		SG_Polygon_Dissolve(pMerged);
+	}
+
+	Get_Shapes()->Select(pMerged, true);
+	Get_Shapes()->Del_Selection();
+	Get_Shapes()->Select(pMerged, false);
+
+	Update_Views(true);
+
+	return( true );
+}
+
+//---------------------------------------------------------
+bool CWKSP_Shapes::_Edit_Split(void)
+{
+	if( Get_Shapes()->Get_Type() == SHAPE_TYPE_Polygon
+	||  Get_Shapes()->Get_Type() == SHAPE_TYPE_Line )
+	{
+		switch( m_Edit_Mode )
+		{
+		default:
+			break;
+
+		//-------------------------------------------------
+		case EDIT_SHAPE_MODE_Normal:
+			m_Edit_Mode	= EDIT_SHAPE_MODE_Split;
+
+			if( m_Edit_Shapes.Get_Count() == 0 )
+			{
+				m_Edit_Shapes.Add_Shape(Get_Shapes()->Get_Selection());
+			}
+
+			if( m_Edit_Shapes.Get_Count() > 1 )
+			{
+				m_Edit_Shapes.Get_Shape(1)->Del_Parts();
+			}
+			else
+			{
+				m_Edit_Shapes.Add_Shape();
+			}
+
+			return( true );
+
+		//-------------------------------------------------
+		case EDIT_SHAPE_MODE_Split:
+			m_Edit_Mode	= EDIT_SHAPE_MODE_Normal;
+
+			CSG_Module	*pModule	= Get_Shapes()->Get_Type() == SHAPE_TYPE_Polygon
+			?	SG_Get_Module_Library_Manager().Get_Module(SG_T("shapes_polygons"), 8)	// Polygon-Line Intersection
+			:	SG_Get_Module_Library_Manager().Get_Module(SG_T("shapes_lines"   ), 6); // Split Lines with Lines
+
+			if(	pModule )
+			{
+				CSG_Shapes	Line(SHAPE_TYPE_Line), Split(Get_Shapes()->Get_Type());
+
+				Line.Add_Shape();
+
+				for(int i=0; i<m_Edit_Shapes.Get_Shape(1)->Get_Point_Count(); i++)
+				{
+					Line.Get_Shape(0)->Add_Point(m_Edit_Shapes.Get_Shape(1)->Get_Point(i));
+				}
+
+				m_Edit_Shapes.Del_Shape(1);
+
+				//-----------------------------------------
+				bool	bResult;
+
+				CSG_Parameters	P; P.Assign(pModule->Get_Parameters());
+
+				pModule->Set_Manager(NULL);
+
+				if( Get_Shapes()->Get_Type() == SHAPE_TYPE_Polygon )
+				{
+					bResult	= pModule->Get_Parameters()->Set_Parameter("POLYGONS" , &m_Edit_Shapes)
+						&&    pModule->Get_Parameters()->Set_Parameter("LINES"    , &Line)
+						&&    pModule->Get_Parameters()->Set_Parameter("INTERSECT", &Split)
+						&&    pModule->Execute();
+				}
+				else //	if( Get_Shapes()->Get_Type() == SHAPE_TYPE_Line )
+				{
+					bResult	= pModule->Get_Parameters()->Set_Parameter("LINES"    , &m_Edit_Shapes)
+						&&    pModule->Get_Parameters()->Set_Parameter("SPLIT"    , &Line)
+						&&    pModule->Get_Parameters()->Set_Parameter("INTERSECT", &Split)
+						&&    pModule->Execute();
+				}
+
+				//-----------------------------------------
+				if( bResult )
+				{
+					if( m_Edit_pShape )
+					{
+						m_Edit_pShape->Assign(Split.Get_Shape(0), false);
+
+						for(int iSplit=1; iSplit<Split.Get_Count(); iSplit++)
+						{
+							CSG_Shape	*pSplit	= Split.Get_Shape(iSplit);
+
+							for(int iPart=0; iPart<pSplit->Get_Part_Count(); iPart++)
+							{
+								for(int iPoint=0, jPart=m_Edit_pShape->Get_Part_Count(); iPoint<pSplit->Get_Point_Count(iPart); iPoint++)
+								{
+									m_Edit_pShape->Add_Point(pSplit->Get_Point(iPoint, iPart), jPart);
+								}
+							}
+						}
+					}
+					else if( Get_Shapes()->Get_Selection_Count() == 1 ) // if( !m_Edit_pShape )
+					{
+						CSG_Shape	*pSelection	= Get_Shapes()->Get_Selection();
+						
+						pSelection->Assign(Split.Get_Shape(0), false);
+
+						for(int iSplit=1; iSplit<Split.Get_Count(); iSplit++)
+						{
+							CSG_Shape	*pSplit	= Get_Shapes()->Add_Shape(Split.Get_Shape(iSplit));
+
+							((CSG_Table_Record *)pSplit)->Assign(pSelection);
+
+							Get_Shapes()->Select(pSplit, true);
+						}
+
+						m_Edit_Shapes.Del_Shapes();
+					}
+				}
+
+				pModule->Get_Parameters()->Assign_Values(&P);
+				pModule->Set_Manager(P.Get_Manager());
+			}
+
+			Update_Views(false);
+
+			return( true );
+		}
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+bool CWKSP_Shapes::_Edit_Move(bool bToggle)
+{
+	if( m_Edit_pShape )
+	{
+		if( bToggle )
+		{
+			switch( m_Edit_Mode )
+			{
+			default:
+				break;
+
+			//---------------------------------------------
+			case EDIT_SHAPE_MODE_Normal:
+				m_Edit_Mode	= EDIT_SHAPE_MODE_Move;
+
+				if( m_Edit_Shapes.Get_Count() > 1 )
+				{
+					m_Edit_Shapes.Get_Shape(1)->Del_Parts();
+				}
+				else
+				{
+					m_Edit_Shapes.Add_Shape();
+				}
+
+				return( true );
+
+			//---------------------------------------------
+			case EDIT_SHAPE_MODE_Move:
+				m_Edit_Mode	= EDIT_SHAPE_MODE_Normal;
+
+				m_Edit_Shapes.Del_Shape(1);
+
+				return( true );
+			}
+		}
+
+		//-------------------------------------------------
+		else // if( !bToggle )
+		{
+			if( m_Edit_Shapes.Get_Count() > 1 && m_Edit_Shapes.Get_Shape(1)->Get_Point_Count() > 1 )
+			{
+				CSG_Point	Move	= CSG_Point(m_Edit_Shapes.Get_Shape(1)->Get_Point(1))
+									- CSG_Point(m_Edit_Shapes.Get_Shape(1)->Get_Point(0));
+
+				m_Edit_Shapes.Get_Shape(1)->Del_Parts();
+
+				if( SG_Get_Length(Move.Get_X(), Move.Get_Y()) > 0.0 )
+				{
+					for(int iPart=0; iPart<m_Edit_pShape->Get_Part_Count(); iPart++)
+					{
+						for(int iPoint=0; iPoint<m_Edit_pShape->Get_Point_Count(iPart); iPoint++)
+						{
+							m_Edit_pShape->Set_Point(Move + m_Edit_pShape->Get_Point(iPoint, iPart), iPoint, iPart);
+						}
+					}
+
+					Update_Views(false);
+
+					return( true );
+				}
+			}
+		}
+	}
+
+	return( false );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
@@ -414,10 +755,11 @@ bool CWKSP_Shapes::_Edit_Shape(void)
 //---------------------------------------------------------
 bool CWKSP_Shapes::_Edit_Shape_Start(void)
 {
-	if( m_Edit_pShape == NULL && Get_Shapes()->Get_Selection(0) != NULL )
+	if( m_Edit_pShape == NULL && Get_Shapes()->Get_Selection(m_Edit_Index) != NULL )
 	{
-		m_Edit_pShape	= m_Edit_Shapes.Add_Shape();
-		m_Edit_pShape->Assign(Get_Shapes()->Get_Selection(0), false);
+		m_Edit_Mode		= EDIT_SHAPE_MODE_Normal;
+
+		m_Edit_pShape	= m_Edit_Shapes.Add_Shape(Get_Shapes()->Get_Selection(m_Edit_Index), SHAPE_COPY_GEOM);
 
 		m_Edit_iPart	= -1;
 		m_Edit_iPoint	= -1;
@@ -442,14 +784,13 @@ bool CWKSP_Shapes::_Edit_Shape_Stop(bool bSave)
 	{
 		if( bSave )
 		{
-			CSG_Shape	*pShape;
+			CSG_Shape	*pShape	= Get_Shapes()->Get_Selection(m_Edit_Index);
 
-			if( (pShape = Get_Shapes()->Get_Selection(0)) == NULL )
+			if( pShape == NULL )
 			{
-				if( (pShape = Get_Shapes()->Add_Shape()) != NULL )
-				{
-					Get_Shapes()->Select(pShape);
-				}
+				Get_Shapes()->Select(pShape = Get_Shapes()->Add_Shape());
+
+				m_Edit_Index	= 0;
 			}
 
 			if( pShape != NULL )
@@ -460,9 +801,11 @@ bool CWKSP_Shapes::_Edit_Shape_Stop(bool bSave)
 
 		m_Edit_Shapes.Del_Shapes();
 		m_Edit_pShape	= NULL;
+		m_Edit_Mode		= EDIT_SHAPE_MODE_Normal;
+
+		Edit_Set_Index(m_Edit_Index);
 
 		Update_Views();
-		_Edit_Set_Attributes();
 
 		return( true );
 	}
@@ -477,7 +820,7 @@ bool CWKSP_Shapes::_Edit_Shape_Add(void)
 	{
 		if( Get_Shapes()->Get_Selection_Count() > 0 )
 		{
-			Get_Shapes()->Select((CSG_Shape*)NULL);
+			Get_Shapes()->Select();	// deselect
 		}
 
 		m_Edit_pShape	= m_Edit_Shapes.Add_Shape();
@@ -515,13 +858,15 @@ bool CWKSP_Shapes::_Edit_Shape_Del(void)
 			{
 				_Edit_Shape_Stop(false);
 
-				Get_Shapes()->Del_Shape(Get_Shapes()->Get_Selection(0));
+				Get_Shapes()->Del_Shape(Get_Shapes()->Get_Selection(m_Edit_Index));
 			}
 			else
 			{
 				Get_Shapes()->Del_Selection();
 			}
 
+			Edit_Set_Index(0);
+
 			Update_Views();
 
 			return( true );
@@ -634,13 +979,24 @@ void CWKSP_Shapes::_Edit_Shape_Draw_Point(wxDC &dc, int x, int y, bool bSelected
 }
 
 //---------------------------------------------------------
-void CWKSP_Shapes::_Edit_Shape_Draw_Move(wxDC &dc, CSG_Rect rWorld, double ClientToWorld, wxPoint Point)
+void CWKSP_Shapes::Edit_Shape_Draw_Move(wxDC &dc, const CSG_Rect &rWorld, const wxPoint &Point)
 {
 	_Edit_Shape_Draw_Point(dc, Point.x, Point.y, false);
 }
 
 //---------------------------------------------------------
-void CWKSP_Shapes::_Edit_Shape_Draw(CWKSP_Map_DC &dc_Map)
+void CWKSP_Shapes::Edit_Shape_Draw_Move(wxDC &dc, const CSG_Rect &rWorld, const wxPoint &Point, const TSG_Point &ptWorld)
+{
+	double	ClientToWorld	= rWorld.Get_XRange() / (double)dc.GetSize().x;
+
+	dc.DrawLine(Point.x, Point.y,
+		(int)((ptWorld.x - rWorld.Get_XMin()) / ClientToWorld),
+		(int)((rWorld.Get_YMax() - ptWorld.y) / ClientToWorld)
+	);
+}
+
+//---------------------------------------------------------
+void CWKSP_Shapes::Edit_Shape_Draw(CWKSP_Map_DC &dc_Map)
 {
 	int		iPart, iPoint;
 
@@ -719,7 +1075,7 @@ void CWKSP_Shapes::_Edit_Snap_Point(CSG_Point &Point, double ClientToWorld)
 //---------------------------------------------------------
 void CWKSP_Shapes::_Edit_Snap_Point(CSG_Point Point, CSG_Point &snap_Point, double &snap_Dist, CSG_Shapes *pShapes, bool bLine)
 {
-	CSG_Shape	*pSelected	= pShapes->Get_Selection();
+	CSG_Shape	*pSelected	= pShapes->Get_Selection(m_Edit_Index);
 
 	if( pShapes->Select(CSG_Rect(Point.Get_X() - snap_Dist, Point.Get_Y() - snap_Dist, Point.Get_X() + snap_Dist, Point.Get_Y() + snap_Dist)) )
 	{
@@ -729,11 +1085,11 @@ void CWKSP_Shapes::_Edit_Snap_Point(CSG_Point Point, CSG_Point &snap_Point, doub
 			{
 				if( bLine )
 				{
-					_Edit_Snap_Point_ToLine(Point, snap_Point, snap_Dist, pShapes->Get_Selection(i));
+					Edit_Snap_Point_ToLine(Point, snap_Point, snap_Dist, pShapes->Get_Selection(i));
 				}
 				else
 				{
-					_Edit_Snap_Point       (Point, snap_Point, snap_Dist, pShapes->Get_Selection(i));
+					_Edit_Snap_Point      (Point, snap_Point, snap_Dist, pShapes->Get_Selection(i));
 				}
 			}
 		}
@@ -768,9 +1124,8 @@ void CWKSP_Shapes::_Edit_Snap_Point(CSG_Point pos_Point, CSG_Point &snap_Point,
 }
 
 //---------------------------------------------------------
-void CWKSP_Shapes::_Edit_Snap_Point_ToLine(CSG_Point pos_Point, CSG_Point &snap_Point, double &snap_Dist, CSG_Shape *pShape)
-{
-}
+void CWKSP_Shapes::Edit_Snap_Point_ToLine(CSG_Point pos_Point, CSG_Point &snap_Point, double &snap_Dist, CSG_Shape *pShape)
+{}
 
 
 ///////////////////////////////////////////////////////////
@@ -780,7 +1135,7 @@ void CWKSP_Shapes::_Edit_Snap_Point_ToLine(CSG_Point pos_Point, CSG_Point &snap_
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-int CWKSP_Shapes::_Edit_Shape_HitTest(CSG_Point pos_Point, double max_Dist, int &pos_iPart, int &pos_iPoint)
+int CWKSP_Shapes::Edit_Shape_HitTest(CSG_Point pos_Point, double max_Dist, int &pos_iPart, int &pos_iPoint)
 {
 	int			Result, iPart, iPoint;
 	double		d, dx, dy;
